@@ -1,14 +1,10 @@
 import re
 import warnings
-from dataclasses import is_dataclass
+from collections.abc import MutableMapping
 from typing import (
     TYPE_CHECKING,
     Any,
-    Dict,
-    MutableMapping,
     Optional,
-    Set,
-    Type,
     Union,
     cast,
 )
@@ -16,7 +12,6 @@ from weakref import WeakKeyDictionary
 
 import fastapi
 from fastapi._compat import (
-    PYDANTIC_V2,
     BaseConfig,
     ModelField,
     PydanticSchemaGenerationError,
@@ -32,11 +27,13 @@ from pydantic import BaseModel
 from pydantic.fields import FieldInfo
 from typing_extensions import Literal
 
+from ._compat import v2
+
 if TYPE_CHECKING:  # pragma: nocover
     from .routing import APIRoute
 
 # Cache for `create_cloned_field`
-_CLONED_TYPES_CACHE: MutableMapping[Type[BaseModel], Type[BaseModel]] = (
+_CLONED_TYPES_CACHE: MutableMapping[type[BaseModel], type[BaseModel]] = (
     WeakKeyDictionary()
 )
 
@@ -58,7 +55,7 @@ def is_body_allowed_for_status_code(status_code: Union[int, str, None]) -> bool:
     return not (current_status_code < 200 or current_status_code in {204, 205, 304})
 
 
-def get_path_param_names(path: str) -> Set[str]:
+def get_path_param_names(path: str) -> set[str]:
     return set(re.findall("{(.*?)}", path))
 
 
@@ -76,10 +73,10 @@ _invalid_args_message = (
 def create_model_field(
     name: str,
     type_: Any,
-    class_validators: Optional[Dict[str, Validator]] = None,
+    class_validators: Optional[dict[str, Validator]] = None,
     default: Optional[Any] = Undefined,
     required: Union[bool, UndefinedType] = Undefined,
-    model_config: Union[Type[BaseConfig], None] = None,
+    model_config: Union[type[BaseConfig], None] = None,
     field_info: Optional[FieldInfo] = None,
     alias: Optional[str] = None,
     mode: Literal["validation", "serialization"] = "validation",
@@ -108,14 +105,12 @@ def create_model_field(
         from fastapi._compat import v1
 
         try:
-            return v1.ModelField(**v1_kwargs)  # type: ignore[no-any-return]
+            return v1.ModelField(**v1_kwargs)  # type: ignore[return-value]
         except RuntimeError:
             raise fastapi.exceptions.FastAPIError(
                 _invalid_args_message.format(type_=type_)
             ) from None
-    elif PYDANTIC_V2:
-        from ._compat import v2
-
+    else:
         field_info = field_info or FieldInfo(
             annotation=type_, default=default, alias=alias
         )
@@ -131,7 +126,7 @@ def create_model_field(
     from fastapi._compat import v1
 
     try:
-        return v1.ModelField(**v1_kwargs)  # type: ignore[no-any-return]
+        return v1.ModelField(**v1_kwargs)
     except RuntimeError:
         raise fastapi.exceptions.FastAPIError(
             _invalid_args_message.format(type_=type_)
@@ -141,13 +136,10 @@ def create_model_field(
 def create_cloned_field(
     field: ModelField,
     *,
-    cloned_types: Optional[MutableMapping[Type[BaseModel], Type[BaseModel]]] = None,
+    cloned_types: Optional[MutableMapping[type[BaseModel], type[BaseModel]]] = None,
 ) -> ModelField:
-    if PYDANTIC_V2:
-        from ._compat import v2
-
-        if isinstance(field, v2.ModelField):
-            return field
+    if isinstance(field, v2.ModelField):
+        return field
 
     from fastapi._compat import v1
 
@@ -157,11 +149,9 @@ def create_cloned_field(
         cloned_types = _CLONED_TYPES_CACHE
 
     original_type = field.type_
-    if is_dataclass(original_type) and hasattr(original_type, "__pydantic_model__"):
-        original_type = original_type.__pydantic_model__
     use_type = original_type
     if lenient_issubclass(original_type, v1.BaseModel):
-        original_type = cast(Type[v1.BaseModel], original_type)
+        original_type = cast(type[v1.BaseModel], original_type)
         use_type = cloned_types.get(original_type)
         if use_type is None:
             use_type = v1.create_model(original_type.__name__, __base__=original_type)
@@ -224,7 +214,7 @@ def generate_unique_id(route: "APIRoute") -> str:
     return operation_id
 
 
-def deep_dict_update(main_dict: Dict[Any, Any], update_dict: Dict[Any, Any]) -> None:
+def deep_dict_update(main_dict: dict[Any, Any], update_dict: dict[Any, Any]) -> None:
     for key, value in update_dict.items():
         if (
             key in main_dict
